Structure
========================

The :class:`pyprocar.core.Structure` class stores structure information. 
Expects a list of atomic symbols, numpy array of fraction coordinates of the atoms, and the atomic lattice matrix.
See :ref:`structure` for further details.

.. autosummary::
   :toctree: _autosummary

   pyprocar.core.Structure